@@ -138,7 +138,7 @@ class ChartEdge(ABC):
 
 
     def _needs_update(self):
-        if hasattr(self, "_sseq"):
+        if self._sseq:
             self._sseq._add_edge_to_update(self)
 
     def replace_source(self, style : Union[ChartClassStyle, str]) -> "ChartEdge":
